/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	Copyright (C) 2010 John Crispin <blogic@openwrt.org>
 */

#include <pj/log.h>

#include "backend.h"
#include "../owsip.h"
#include "../call/call.h"

#define TOUT_PICKUP	3
#define TOUT_HANGUP	30

#define THIS_FILE       "b/echo.c"

struct echo_priv {
	pjsua_call_id call_id;
	pj_timer_entry pickup;
	pj_timer_entry hangup;
};

static void
echo_connect(struct call *c)
{
	pjsua_call_info ci;
	pjsua_call_get_info(c->call_id, &ci);
	if (ci.media_status == PJSUA_CALL_MEDIA_ACTIVE)
		pjsua_conf_connect(ci.conf_slot, ci.conf_slot);
}

static void
echo_hangup_cb(pj_timer_heap_t *timer_heap, struct pj_timer_entry *entry)
{
	struct echo_priv *p = (struct echo_priv*) entry->user_data;
	PJ_LOG(3, (THIS_FILE, "auto hangup"));
	owsip_hangup(p->call_id);
}

static void
echo_connect_cb(pj_timer_heap_t *timer_heap, struct pj_timer_entry *entry)
{
	struct echo_priv *p = (struct echo_priv*) entry->user_data;
	pj_time_val d;
	PJ_LOG(3, (THIS_FILE, "auto answering incoming call"));
	owsip_pickup(p->call_id);
	d.sec = TOUT_HANGUP;
	d.msec = 0;
	p->hangup.cb = echo_hangup_cb;
	p->hangup.user_data = p;
	pjsua_schedule_timer(&p->hangup, &d);
}

static void
echo_start(struct call *c)
{
	struct echo_priv *p = calloc(1, sizeof(struct echo_priv));
	pj_time_val d;
	d.sec = TOUT_PICKUP;
	d.msec = 0;
	p->call_id = c->call_id;
	p->pickup.cb = echo_connect_cb;
	p->pickup.user_data = c->backend_priv = p;
	pjsua_schedule_timer(&p->pickup, &d);
}

static void
echo_stop(struct call *c)
{
	struct echo_priv *p = (struct echo_priv*) c->backend_priv;
	pjsua_cancel_timer(&p->pickup);
	pjsua_cancel_timer(&p->hangup);
	free(p);
}

static struct backend echo = {
	.ports = 1,
	.name = "echo",
	.connect = echo_connect,
	.start = echo_start,
	.stop = echo_stop,
};

BACKEND(echo)
