/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	Copyright (C) 2010 John Crispin <blogic@openwrt.org>
 */

#include <pj/log.h>

#include "backend.h"
#include "../config.h"
#include "../call/call.h"

#define THIS_FILE	"b/oss.c"

static void
oss_init(struct owsip *owsip)
{
	unsigned int count = 16;
	pjmedia_aud_dev_info info[16];
	int i;

	pjsua_enum_aud_devs(info, &count);
	PJ_LOG(3, (THIS_FILE, "audio devices"));
	for(i = 0; i < count; i++)
		PJ_LOG(3, (THIS_FILE, "audio device %s is at position %d", info[i].name, i));
	PJ_LOG(3, (THIS_FILE, "using device at position %d", owsip->conf.ossdev));
	pjsua_set_snd_dev(owsip->conf.ossdev, owsip->conf.ossdev);
}

static void
oss_connect(struct call *c)
{
	pjsua_call_info ci;
	pjsua_call_get_info(c->call_id, &ci);
	if (ci.media_status == PJSUA_CALL_MEDIA_ACTIVE) {
		pjsua_conf_connect(ci.conf_slot, 0);
		pjsua_conf_connect(0, ci.conf_slot);
	}
}

static struct backend oss_backend = {
	.ports = 1,
	.name = "oss",
	.init = oss_init,
	.connect = oss_connect,
};

BACKEND(oss_backend)
