/*
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	Copyright (C) 2010 John Crispin <blogic@openwrt.org>
 */

#ifndef _OWSIP_CONFIG_H__
#define _OWSIP_CONFIG_H__

#include <uci.h>
#include <ucimap.h>

#include "backend/backend.h"

struct rule
{
	struct list_head list;
	struct ucimap_section_data map;
	char *name;
	char *handler;
	char *account;
	char *match;
	int start;
	int stop;
	pjsua_acc_id acc_id;
};

struct account
{
	struct list_head list;
	struct ucimap_section_data map;
	char *name;
	char *realm;
	char *username;
	char *password;
	int def_acc;
	int disabled;
	char *cport;
	int port;

	pjsua_acc_config acc_config;
	pjsua_acc_id acc_id;
};

struct contact
{
	struct list_head list;
        struct ucimap_section_data map;
	char *name;
	char *acc_name;
	char *desc;
	char *code;
	char *match;
	char *dial;
	char *type;
	struct account *account;
};

struct port
{
	struct list_head list;
        struct ucimap_section_data map;
	int id;
	int noring;
	int nodial;
	char *led;
	char *name;
};

struct owsip_conf
{
	struct ucimap_section_data map;
	char *name;
	char *backend;
	int ossdev;
	int log_level;
	char *interface;
	int local_port;
	int rtp_port;
	char *outbound;
	int revert;
	char *cid;
	char *locale;
};

struct owsip
{
	struct owsip_conf conf;
	struct backend *backend;

	struct list_head ports;
	struct list_head accounts;
	struct list_head contacts;
	struct list_head leds;

	struct account *def_acc;

	struct list_head rules;
	struct rule policy;

	pjsua_config cfg;
	pjsua_logging_config log_cfg;
};

struct owsip* config_load(void);
int config_free(struct owsip *o);

#endif
